@@ -6,6 +6,8 @@ use VCI::VCS::Hg::File;
 extends 'VCI::Abstract::Directory';
 with 'VCI::VCS::Hg::Committable';
 
+sub build_revision { return 'tip' }
+
 sub build_contents {
     my $self = shift;
     my $ls = $self->project->x_get(['raw-file/', $self->revision, $self->path]);
@@ -30,9 +32,7 @@ sub build_contents {
                                                 is_executable => $executable,
                                                 content_size => $size,
                                                 project => $self->project,
-                                                parent => $self,
-                                                # XXX This isn't really right.
-                                                revision => $self->revision));
+                                                parent => $self));
     }
     return \@contents;
 }
