@@ -39,6 +39,18 @@ sub build_contents {
     return \@contents;
 }
 
+# We have to do this because ->isa File or Directory never
+# returns true on a FileOrDirectory.
+sub _me_from {
+    my $self = shift;
+    my $orig_class = blessed $self;
+    bless $self, 'VCI::VCS::Svn::FileOrDirectory';
+    my $ret = $self->SUPER::_me_from(@_);
+    bless $self, $orig_class;
+    bless $ret, $orig_class;
+    return $ret;
+};
+
 __PACKAGE__->meta->make_immutable;
 
 1;
